.. MEDS-TAB documentation master file, created by
   sphinx-quickstart on Mon Jun  3 20:41:52 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to MEDS-Tab's documentation!
====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   overview
   installation
   usage
   implementation
   computational-performance
   xgboost-performance
   api
